package PureMessage::Map::ldap;

use strict;
use base qw(PureMessage::List::Base::ldap PureMessage::Map);
use Carp qw(croak);

sub new {
    my $class = shift;
    my $self  = $class->SUPER::new( @_ );
    # check for "attr" argument, which is required for maps
    my $attr  = $self->{args}{attr} || die("No attr statement provided");
    return $self;
}

sub transform {
    my ($self, @matchTab) = @_;
    my $attr = $self->{args}{attr};
    my @items;
    foreach my $match ( @matchTab ) {    
    	my $f = $self->{args}{match};
		$match =~ s/([\\\(\)\*\0-\37])/sprintf("\\%02x",ord($1))/sge;
    	if (($f =~ /\%[d|u]/) && ($match =~ /@/)) {
        	(my $user, my $domain) = split(/@/,$match);
        	$f =~ s/%u/$user/g;
        	$f =~ s/%d/$domain/g;
    	}
    	$f =~ s/%s/$match/g;
    	my $m = $self->ldap_search( base => $self->{args}{base},
                                filter => $f,
                                scope => $self->{args}{scope},
                                attrs => [$attr],
                              );
    	$m->code and croak $m->error;
		my $found_match=0;
    	for my $e ($m->all_entries) {
			$e->dump if $self->{verbose};
			$found_match=1;
        	push( @items, $e->get_value($attr) );
    	}
		push @items, $match unless $found_match;
	 }
    return wantarray ? @items : $items[0];
}

1;
